@@ -24,6 +24,8 @@ If this file is the __init__.py of some package, it should be a
 description of the package.
 
 """ 
+from __future__ import unicode_literals
+from __future__ import print_function
 
 import os
 import os.path
@@ -32,7 +34,7 @@ from reahl.sqlalchemysupport import SqlAlchemyControl
 
 eggName = os.path.basename(os.getcwd())
 reahlsystem.root_egg = eggName
-reahlsystem.connection_uri = 'postgres://rhug:rhug@localhost/rhug'
+reahlsystem.connection_uri = 'postgresql://rhug:rhug@localhost/rhug'
 #reahlsystem.connection_uri = 'sqlite:////tmp/test.db'
 reahlsystem.orm_control = SqlAlchemyControl(echo=False)
 
