@@ -18,8 +18,12 @@
 """A user interface for logging in, registering, etc using :class:`~reahl.systemaccountmodel.EmailAndPasswordSystemAccount`."""
 
 
+from __future__ import unicode_literals
+from __future__ import print_function
 from reahl.component.i18n import Translator
-from reahl.web.fw import UserInterface, Widget, WebExecutionContext, Url
+from reahl.web.fw import UserInterface
+from reahl.web.fw import WebExecutionContext
+from reahl.web.fw import Widget
 from reahl.web.ui import Form, InputGroup, LabelledBlockInput, Button, CheckboxInput, \
                          TextInput, PasswordInput, H, P, A, Div, CueInput,\
                          CheckCheckboxButton, PopupA, DialogButton, ErrorFeedbackMessage
@@ -29,7 +33,7 @@ from reahl.component.decorators import deprecated
 from reahl.systemaccountmodel import EmailAndPasswordSystemAccount, NotUniqueException, NewPasswordRequest, \
      AccountManagementInterface
 
-_ = Translator(u'reahl-domainui')
+_ = Translator('reahl-domainui')
 
 
 class TitledWidget(Widget):
@@ -41,7 +45,7 @@ class TitledWidget(Widget):
 class ActionButtonGroup(InputGroup):
     def __init__(self, view, label_text=None):
         super(ActionButtonGroup, self).__init__(view, label_text=label_text)
-        self.add_to_attribute(u'class', [u'action_buttons'])
+        self.add_to_attribute('class', ['action_buttons'])
 
 
 class LoginForm(Form):
@@ -52,17 +56,17 @@ class LoginForm(Form):
         if self.exception:
             self.add_child(ErrorFeedbackMessage(view, self.exception.as_user_message()))
         
-        login_inputs = self.add_child(InputGroup(view, label_text=_(u'Please specify:')))
-        email_cue = P(view, _(u'The email address you used to register here.'))
+        login_inputs = self.add_child(InputGroup(view, label_text=_('Please specify:')))
+        email_cue = P(view, _('The email address you used to register here.'))
         login_inputs.add_child(CueInput(TextInput(self, self.account_management_interface.fields.email), email_cue))
         
-        password_cue = P(view, _(u'The secret password you supplied upon registration.') )
+        password_cue = P(view, _('The secret password you supplied upon registration.') )
         password_cue_input = CueInput(PasswordInput(self, self.account_management_interface.fields.password), password_cue)
-        forgot_password_bookmark = self.user_interface.get_bookmark(relative_path=u'/resetPassword',
-                                                            description=_(u'Forgot your password?'))
+        forgot_password_bookmark = self.user_interface.get_bookmark(relative_path='/resetPassword',
+                                                            description=_('Forgot your password?'))
         password_cue_input.input_part.add_child(A.from_bookmark(view, forgot_password_bookmark))
         login_inputs.add_child(password_cue_input)
-        stay_cue = P(view, _(u'If selected, you will stay logged in for longer.'))
+        stay_cue = P(view, _('If selected, you will stay logged in for longer.'))
         login_inputs.add_child(CueInput(CheckboxInput(self, self.account_management_interface.fields.stay_logged_in), stay_cue))
 
         login_buttons = self.add_child(ActionButtonGroup(view))
@@ -72,7 +76,7 @@ class LoginForm(Form):
 class LoginWidget(TitledWidget):
     def __init__(self, view, account_management_interface):
         super(LoginWidget, self).__init__(view)
-        self.add_child(LoginForm(view, u'login_form', account_management_interface))
+        self.add_child(LoginForm(view, 'login_form', account_management_interface))
 
 
 class UniqueEmailConstraint(RemoteConstraint):
@@ -86,7 +90,7 @@ class UniqueEmailConstraint(RemoteConstraint):
 class RegisterWidget(TitledWidget):
     def __init__(self, view, bookmarks, account_management_interface):
         super(RegisterWidget, self).__init__(view)
-        self.add_child(RegisterForm(view, u'register', bookmarks, account_management_interface))
+        self.add_child(RegisterForm(view, 'register', bookmarks, account_management_interface))
 
 
 class RegisterForm(Form):
@@ -103,40 +107,40 @@ class RegisterForm(Form):
         self.create_action_buttons()
         
     def create_identification_inputs(self):
-        identification_inputs = self.add_child(InputGroup(self.view, label_text=_(u'How will you identify yourself?')))
+        identification_inputs = self.add_child(InputGroup(self.view, label_text=_('How will you identify yourself?')))
         
-        email_cue = P(self.view, _(u'You identify yourself to us by your email address.' \
-                                   u'This information is not divulged to others.'))
-        error_message=_(u'Sorry, you can only register once per email address and someone is ' \
-                        u'already registered as $value. Did you perhaps register long ago?')
+        email_cue = P(self.view, _('You identify yourself to us by your email address.' \
+                                   'This information is not divulged to others.'))
+        error_message=_('Sorry, you can only register once per email address and someone is ' \
+                        'already registered as $value. Did you perhaps register long ago?')
                         
         unique_email_field = self.account_management_interface.fields.email.as_with_validation_constraint(UniqueEmailConstraint(error_message))
         identification_inputs.add_child(CueInput(TextInput(self, unique_email_field), email_cue))
         
-        password_cue = P(self.view, _(u'Upon logging in, you will be asked for your password. Your password should be a '\
-                                 u'secret, known only to yourself, and be difficult to guess.') )
+        password_cue = P(self.view, _('Upon logging in, you will be asked for your password. Your password should be a '\
+                                 'secret, known only to yourself, and be difficult to guess.') )
         identification_inputs.add_child(CueInput(PasswordInput(self, self.account_management_interface.fields.password), 
                                            password_cue))
-        repeat_password_cue = P(self.view, _(u'By typing the same password again you help us to make sure you did not make any typing mistakes.'))
+        repeat_password_cue = P(self.view, _('By typing the same password again you help us to make sure you did not make any typing mistakes.'))
         identification_inputs.add_child(CueInput(PasswordInput(self, self.account_management_interface.fields.repeat_password), 
                                            repeat_password_cue))
 
     def create_terms_inputs(self):
-        terms_inputs = self.add_child(InputGroup(self.view, label_text=_(u'Terms and conditions')))
+        terms_inputs = self.add_child(InputGroup(self.view, label_text=_('Terms and conditions')))
 
-        terms_prompt = P(self.view, text=_(u'Please read and accept our {terms}. You may also be interested '
-                                           u'to read our {privacypolicy} and our {disclaimer}.'))
+        terms_prompt = P(self.view, text=_('Please read and accept our {terms}. You may also be interested '
+                                           'to read our {privacypolicy} and our {disclaimer}.'))
         popup = PopupA(self.view, self.bookmarks.terms_bookmark, '#terms', close_button=False)
         terms_inputs.add_child(terms_prompt.format(terms=popup,
                                                    privacypolicy=PopupA(self.view, self.bookmarks.privacy_bookmark, '#privacypolicy'),
                                                    disclaimer=PopupA(self.view, self.bookmarks.disclaimer_bookmark, '#disclaimer')))
         
-        terms_cue = P(self.view, _(u'You can only register if you agree to the terms and conditions.'))
+        terms_cue = P(self.view, _('You can only register if you agree to the terms and conditions.'))
         accept_checkbox = CheckboxInput(self, self.account_management_interface.fields.accept_terms)
         terms_inputs.add_child(CueInput(accept_checkbox, terms_cue))
 
-        popup.add_button(CheckCheckboxButton(_(u'Accept'), accept_checkbox))
-        popup.add_button(DialogButton(_(u'Cancel')))
+        popup.add_button(CheckCheckboxButton(_('Accept'), accept_checkbox))
+        popup.add_button(DialogButton(_('Cancel')))
     
     def create_action_buttons(self):
         actions = self.add_child(ActionButtonGroup(self.view))
@@ -146,7 +150,7 @@ class RegisterForm(Form):
 class VerifyEmailWidget(TitledWidget):
     def __init__(self, view, account_management_interface):
         super(VerifyEmailWidget, self).__init__(view)
-        self.add_child(VerifyForm(view, u'verify', account_management_interface))
+        self.add_child(VerifyForm(view, 'verify', account_management_interface))
 
 
 class VerifyForm(Form):
@@ -157,7 +161,7 @@ class VerifyForm(Form):
         if self.exception:
             self.add_child(ErrorFeedbackMessage(view, self.exception.as_user_message()))
 
-        identification_inputs = self.add_child(InputGroup(view, label_text=_(u'Please supply the following details')))
+        identification_inputs = self.add_child(InputGroup(view, label_text=_('Please supply the following details')))
         identification_inputs.add_child(LabelledBlockInput(TextInput(self, account_management_interface.fields.email)))
         identification_inputs.add_child(LabelledBlockInput(TextInput(self, account_management_interface.fields.secret)))
         identification_inputs.add_child(LabelledBlockInput(PasswordInput(self, account_management_interface.fields.password)))
@@ -178,12 +182,12 @@ class RegisterHelpWidget(TitledWidget):
 
 class RegisterHelpForm(Form):
     def __init__(self, view, account_management_interface):
-        super(RegisterHelpForm, self).__init__(view, u'register_help')
+        super(RegisterHelpForm, self).__init__(view, 'register_help')
 
         if self.exception:
             self.add_child(ErrorFeedbackMessage(view, self.exception.as_user_message()))
         
-        inputs = self.add_child(InputGroup(view, label_text=_(u'Please supply the email address you tried to register with.')))
+        inputs = self.add_child(InputGroup(view, label_text=_('Please supply the email address you tried to register with.')))
         inputs.add_child(LabelledBlockInput(TextInput(self, account_management_interface.fields.email)))
         
         actions = self.add_child(ActionButtonGroup(view))
@@ -193,104 +197,104 @@ class RegisterHelpForm(Form):
 class RegistrationDuplicatedWidget(TitledWidget):
     def __init__(self, view, account_management_interface):
         super(RegistrationDuplicatedWidget, self).__init__(view)
-        self.add_child(P(view, text=_(u'You are trying to register using the email address "%s"') % account_management_interface.email))
-        self.add_child(P(view, text=_(u'That address is already registered and active on the system.' \
-                                      u'This means that you (or someone else) must have registered using that email address' \
-                                      u' previously.')))
+        self.add_child(P(view, text=_('You are trying to register using the email address "%s"') % account_management_interface.email))
+        self.add_child(P(view, text=_('That address is already registered and active on the system.' \
+                                      'This means that you (or someone else) must have registered using that email address' \
+                                      ' previously.')))
 
-        forgot_password_bookmark = self.user_interface.get_bookmark(relative_path=u'/resetPassword')
-        last_p = P(view, text=_(u'You can gain access to this account by following our {procedure}.'))
-        self.add_child(last_p.format(procedure=A.from_bookmark(view, forgot_password_bookmark.with_description(_(u' password reset procedure')))))
+        forgot_password_bookmark = self.user_interface.get_bookmark(relative_path='/resetPassword')
+        last_p = P(view, text=_('You can gain access to this account by following our {procedure}.'))
+        self.add_child(last_p.format(procedure=A.from_bookmark(view, forgot_password_bookmark.with_description(_(' password reset procedure')))))
 
         
 class RegistrationPendingWidget(TitledWidget):
     def __init__(self, view, account_management_interface):
         super(RegistrationPendingWidget, self).__init__(view)
         config = WebExecutionContext.get_context().config
-        self.add_child(P(view, text=_(u'There is a registration pending for email address "%s".') % account_management_interface.email))
-        self.add_child(P(view, text=_(u'Before you can log in using it, you need to act on the automated email '\
-                                      u'sent to that address. It looks like you did not do that.')))
-        self.add_child(P(view, text=_(u'You should receive the automated email anything between a minute to an hour after '\
-                                      u'registration. Sometimes though, your email software may mistakenly identify our '\
-                                      u'email as junk email. If this happens it will be hidden away in a "junk email" '\
-                                      u'folder or just not shown to you.')))
-        self.add_child(P(view, text=_(u'You can have the email re-sent to you by clicking on the button below.')))
-        self.add_child(P(view, text=_(u'Before you do that, however, please make sure that your email system will allow '\
-                                      u'emails from "%s" through to you.') % config.accounts.admin_email))
+        self.add_child(P(view, text=_('There is a registration pending for email address "%s".') % account_management_interface.email))
+        self.add_child(P(view, text=_('Before you can log in using it, you need to act on the automated email '\
+                                      'sent to that address. It looks like you did not do that.')))
+        self.add_child(P(view, text=_('You should receive the automated email anything between a minute to an hour after '\
+                                      'registration. Sometimes though, your email software may mistakenly identify our '\
+                                      'email as junk email. If this happens it will be hidden away in a "junk email" '\
+                                      'folder or just not shown to you.')))
+        self.add_child(P(view, text=_('You can have the email re-sent to you by clicking on the button below.')))
+        self.add_child(P(view, text=_('Before you do that, however, please make sure that your email system will allow '\
+                                      'emails from "%s" through to you.') % config.accounts.admin_email))
 
         self.add_child(RegistrationPendingForm(view))
 
 
 class RegistrationPendingForm(Form):
     def __init__(self, view):
-        super(RegistrationPendingForm, self).__init__(view, u'register_pending')
+        super(RegistrationPendingForm, self).__init__(view, 'register_pending')
 
         if self.exception:
             self.add_child(ErrorFeedbackMessage(view, self.exception.as_user_message()))
         
-        actions = self.add_child(ActionButtonGroup(view, label_text=_(u'Re-send registration email')))
+        actions = self.add_child(ActionButtonGroup(view, label_text=_('Re-send registration email')))
         actions.add_child(Button(self, self.user_interface.account_management_interface.events.resend_event))
 
 
 class RegistrationNotFoundWidget(TitledWidget):
     def __init__(self, view, account_management_interface):
         super(RegistrationNotFoundWidget, self).__init__(view)
-        self.add_child(P(view, text=_(u'There is no record of someone trying to register the email address "%s".') % account_management_interface.email))
-        self.add_child(P(view, text=_(u'Perhaps you mistyped your email address when registering? The system also removes ' \
-                                      u'such a registration request if you take a long time to get around to verifying it.')))
+        self.add_child(P(view, text=_('There is no record of someone trying to register the email address "%s".') % account_management_interface.email))
+        self.add_child(P(view, text=_('Perhaps you mistyped your email address when registering? The system also removes ' \
+                                      'such a registration request if you take a long time to get around to verifying it.')))
 
-        register_bookmark = self.user_interface.get_bookmark(relative_path=u'/register')
-        last_p = P(view, text=_(u'Whatever the case, please {register} to rectify the problem.'))
-        self.add_child(last_p.format(register=A.from_bookmark(view, register_bookmark.with_description(_(u'register again')))))
+        register_bookmark = self.user_interface.get_bookmark(relative_path='/register')
+        last_p = P(view, text=_('Whatever the case, please {register} to rectify the problem.'))
+        self.add_child(last_p.format(register=A.from_bookmark(view, register_bookmark.with_description(_('register again')))))
 
 
 class RegistrationEmailSentWidget(TitledWidget):
     def __init__(self, view, account_management_interface):
         super(RegistrationEmailSentWidget, self).__init__(view)
-        self.add_child(P(view, text=_(u'A new registration email was sent to "%s"') % account_management_interface.email))
-        self.add_child(P(view, text=_(u'Please watch your inbox and follow the instructions in the email.')))
+        self.add_child(P(view, text=_('A new registration email was sent to "%s"') % account_management_interface.email))
+        self.add_child(P(view, text=_('Please watch your inbox and follow the instructions in the email.')))
 
     
 
 class ThanksWidget(TitledWidget):
     def __init__(self, view):
         super(ThanksWidget, self).__init__(view)
-        self.add_child(P(view, text=_(u'Thank you for verifying your email address.')))
-        self.add_child(P(view, text=_(u'Your account is now active, and you can proceed to log in using the details you provided.')))
+        self.add_child(P(view, text=_('Thank you for verifying your email address.')))
+        self.add_child(P(view, text=_('Your account is now active, and you can proceed to log in using the details you provided.')))
 
 
 class CongratsWidget(TitledWidget):
     def __init__(self, view, account_management_interface, register_help_bookmark):
         super(CongratsWidget, self).__init__(view)
-        self.add_child(P(view, text=_(u'You have successfully registered.')))
-        self.add_child(P(view, text=_(u'Before we can allow you to log in, however, you need to prove to us that you are indeed the owner of %s.') % account_management_interface.email))
-        self.add_child(P(view, text=_(u'You can do that by following instructions just emailed to that address.')))
-        self.add_child(P(view, text=_(u'Sometimes these emails arrive immediately, but they may also be delayed.')))
-        last_p = P(view, text=_(u'If you do not receive the email within an hour or so, please follow {trouble}.'))
-        self.add_child(last_p.format(trouble=A.from_bookmark(view, register_help_bookmark.with_description(_(u'our troubleshooting procedure')))))
+        self.add_child(P(view, text=_('You have successfully registered.')))
+        self.add_child(P(view, text=_('Before we can allow you to log in, however, you need to prove to us that you are indeed the owner of %s.') % account_management_interface.email))
+        self.add_child(P(view, text=_('You can do that by following instructions just emailed to that address.')))
+        self.add_child(P(view, text=_('Sometimes these emails arrive immediately, but they may also be delayed.')))
+        last_p = P(view, text=_('If you do not receive the email within an hour or so, please follow {trouble}.'))
+        self.add_child(last_p.format(trouble=A.from_bookmark(view, register_help_bookmark.with_description(_('our troubleshooting procedure')))))
 
 
 class ResetPasswordWidget(TitledWidget):
     def __init__(self, view, account_management_interface):
         super(ResetPasswordWidget, self).__init__(view)
-        explanation = P(view, text=_(u'To ensure you are not an impostor, resetting your password is a two step '\
-                         u'process: First, we send a "secret key" to your registered email address. '\
-                         u'Then, {choose_password}. But you need that secret key for the last step in order to prove '\
-                         u'that you are indeed the owner of the registered email address.'))
-        link_text = _(u'you can choose a new password')
-        step2_bookmark = self.user_interface.get_bookmark(relative_path=u'/choosePassword', description=link_text)
+        explanation = P(view, text=_('To ensure you are not an impostor, resetting your password is a two step '\
+                         'process: First, we send a "secret key" to your registered email address. '\
+                         'Then, {choose_password}. But you need that secret key for the last step in order to prove '\
+                         'that you are indeed the owner of the registered email address.'))
+        link_text = _('you can choose a new password')
+        step2_bookmark = self.user_interface.get_bookmark(relative_path='/choosePassword', description=link_text)
         self.add_child(explanation.format(choose_password=A.from_bookmark(view, step2_bookmark)))
         self.add_child(ResetPasswordForm(view, account_management_interface))
 
 
 class ResetPasswordForm(Form):
     def __init__(self, view, account_management_interface):
-        super(ResetPasswordForm, self).__init__(view, u'reset_password')
+        super(ResetPasswordForm, self).__init__(view, 'reset_password')
 
         if self.exception:
             self.add_child(ErrorFeedbackMessage(view, self.exception.as_user_message()))
 
-        inputs = self.add_child(InputGroup(view, label_text=_(u'Request a secret key')))
+        inputs = self.add_child(InputGroup(view, label_text=_('Request a secret key')))
         inputs.add_child(LabelledBlockInput(TextInput(self, account_management_interface.fields.email)))
 
         actions = self.add_child(ActionButtonGroup(view))
@@ -300,10 +304,10 @@ class ResetPasswordForm(Form):
 class ChoosePasswordWidget(TitledWidget):
     def __init__(self, view, account_management_interface):
         super(ChoosePasswordWidget, self).__init__(view)
-        explanation = P(view, text=_(u'Do you have your secret key? You can only choose a new password if you {reset_password}.'))
+        explanation = P(view, text=_('Do you have your secret key? You can only choose a new password if you {reset_password}.'))
         
-        link_text = _(u'previously requested a secret key to be sent to your registered email address')
-        step1_bookmark = self.user_interface.get_bookmark(relative_path=u'/resetPassword', description=link_text)
+        link_text = _('previously requested a secret key to be sent to your registered email address')
+        step1_bookmark = self.user_interface.get_bookmark(relative_path='/resetPassword', description=link_text)
 
         self.add_child(explanation.format(reset_password=A.from_bookmark(view, step1_bookmark)))
         self.add_child(ChoosePasswordForm(view, account_management_interface))
@@ -312,12 +316,12 @@ class ChoosePasswordWidget(TitledWidget):
 class ChoosePasswordForm(Form):
     def __init__(self, view, account_management_interface):
         self.account_management_interface = account_management_interface
-        super(ChoosePasswordForm, self).__init__(view, u'choose_password')
+        super(ChoosePasswordForm, self).__init__(view, 'choose_password')
 
         if self.exception:
             self.add_child(ErrorFeedbackMessage(view, self.exception.as_user_message()))
 
-        inputs = self.add_child(InputGroup(view, label_text=_(u'Choose a new password')))
+        inputs = self.add_child(InputGroup(view, label_text=_('Choose a new password')))
         inputs.add_child(LabelledBlockInput(TextInput(self, account_management_interface.fields.email)))
         inputs.add_child(LabelledBlockInput(TextInput(self, account_management_interface.fields.secret)))
         inputs.add_child(LabelledBlockInput(PasswordInput(self, account_management_interface.fields.password)))
@@ -335,7 +339,7 @@ class ChoosePasswordForm(Form):
 class PasswordChangedWidget(TitledWidget):
     def __init__(self, view):
         super(PasswordChangedWidget, self).__init__(view)
-        self.add_child(P(view, text=_(u'Thank you, your password has been changed successfully.')))
+        self.add_child(P(view, text=_('Thank you, your password has been changed successfully.')))
 
 
 class AccountUI(UserInterface):
@@ -381,21 +385,21 @@ class AccountUI(UserInterface):
         self.assemble_register()
 
     def assemble_login(self):
-        login_local = self.define_view(u'/login', title=_(u'Log in with email and password'), detour=True)
-        login_local.set_slot(u'main_slot', LoginWidget.factory(self.account_management_interface))
+        login_local = self.define_view('/login', title=_('Log in with email and password'), detour=True)
+        login_local.set_slot('main_slot', LoginWidget.factory(self.account_management_interface))
 
         self.define_return_transition(self.account_management_interface.events.login_event, login_local)
 
 
     def assemble_reset_password(self):
-        reset_password = self.define_view(u'/resetPassword', title=_(u'Reset a password: Step 1'))
-        reset_password.set_slot(u'main_slot', ResetPasswordWidget.factory(self.account_management_interface))
+        reset_password = self.define_view('/resetPassword', title=_('Reset a password: Step 1'))
+        reset_password.set_slot('main_slot', ResetPasswordWidget.factory(self.account_management_interface))
         
-        choose_password = self.define_view(u'/choosePassword', title=_(u'Reset a password: Step 2'))
-        choose_password.set_slot(u'main_slot', ChoosePasswordWidget.factory(self.account_management_interface))
+        choose_password = self.define_view('/choosePassword', title=_('Reset a password: Step 2'))
+        choose_password.set_slot('main_slot', ChoosePasswordWidget.factory(self.account_management_interface))
         
-        password_changed = self.define_view(u'/passwordChanged', title=_(u'Password change complete'))
-        password_changed.set_slot(u'main_slot', PasswordChangedWidget.factory())
+        password_changed = self.define_view('/passwordChanged', title=_('Password change complete'))
+        password_changed.set_slot('main_slot', PasswordChangedWidget.factory())
 
         self.define_transition(self.account_management_interface.events.reset_password_event, 
                             reset_password, choose_password)
@@ -404,20 +408,20 @@ class AccountUI(UserInterface):
 
 
     def assemble_register_help(self):
-        register_help = self.define_view(u'/registerHelp', title=_(u'Problems registering?'))
-        register_help.set_slot(u'main_slot', RegisterHelpWidget.factory(self.account_management_interface))
+        register_help = self.define_view('/registerHelp', title=_('Problems registering?'))
+        register_help.set_slot('main_slot', RegisterHelpWidget.factory(self.account_management_interface))
         
-        help_duplicate = self.define_view(u'/registerHelp/duplicate', title=_(u'Address already registered'))
-        help_duplicate.set_slot(u'main_slot', RegistrationDuplicatedWidget.factory(self.account_management_interface))
+        help_duplicate = self.define_view('/registerHelp/duplicate', title=_('Address already registered'))
+        help_duplicate.set_slot('main_slot', RegistrationDuplicatedWidget.factory(self.account_management_interface))
         
-        help_pending = self.define_view(u'/registerHelp/pending', title=_(u'Registration still pending'))
-        help_pending.set_slot(u'main_slot', RegistrationPendingWidget.factory(self.account_management_interface))
+        help_pending = self.define_view('/registerHelp/pending', title=_('Registration still pending'))
+        help_pending.set_slot('main_slot', RegistrationPendingWidget.factory(self.account_management_interface))
         
-        help_reregister = self.define_view(u'/registerHelp/reregister', title=_(u'Registration not found'))
-        help_reregister.set_slot(u'main_slot', RegistrationNotFoundWidget.factory(self.account_management_interface))
+        help_reregister = self.define_view('/registerHelp/reregister', title=_('Registration not found'))
+        help_reregister.set_slot('main_slot', RegistrationNotFoundWidget.factory(self.account_management_interface))
         
-        help_sent = self.define_view(u'/registerHelp/pending/sent', title=_(u'Registration email sent'))
-        help_sent.set_slot(u'main_slot', RegistrationEmailSentWidget.factory(self.account_management_interface))
+        help_sent = self.define_view('/registerHelp/pending/sent', title=_('Registration email sent'))
+        help_sent.set_slot('main_slot', RegistrationEmailSentWidget.factory(self.account_management_interface))
         
         investigate_event = self.account_management_interface.events.investigate_event
         self.define_transition(investigate_event, 
@@ -435,23 +439,23 @@ class AccountUI(UserInterface):
 
 
     def assemble_register(self):
-        register = self.define_view(u'/register', title=_(u'Register with us'))
-        register.set_slot(u'main_slot', RegisterWidget.factory(self.bookmarks, self.account_management_interface))
+        register = self.define_view('/register', title=_('Register with us'))
+        register.set_slot('main_slot', RegisterWidget.factory(self.bookmarks, self.account_management_interface))
         
-        congrats = self.define_view(u'/congrats', title=_(u'Congratulations'))
-        congrats.set_slot(u'main_slot', CongratsWidget.factory(self.account_management_interface, self.register_help_bookmark))
+        congrats = self.define_view('/congrats', title=_('Congratulations'))
+        congrats.set_slot('main_slot', CongratsWidget.factory(self.account_management_interface, self.register_help_bookmark))
         
-        verify = self.define_view(u'/verify', title=_(u'Verify pending registration'))
-        verify.set_slot(u'main_slot', VerifyEmailWidget.factory(self.account_management_interface))
+        verify = self.define_view('/verify', title=_('Verify pending registration'))
+        verify.set_slot('main_slot', VerifyEmailWidget.factory(self.account_management_interface))
         
-        thanks = self.define_view(u'/thanks', title=_(u'Thanks for all your troubles'))
-        thanks.set_slot(u'main_slot', ThanksWidget.factory())
+        thanks = self.define_view('/thanks', title=_('Thanks for all your troubles'))
+        thanks.set_slot('main_slot', ThanksWidget.factory())
 
         self.define_transition(self.account_management_interface.events.register_event, register, congrats)
         self.define_transition(self.account_management_interface.events.verify_event, verify, thanks)
 
 
-@deprecated(u'Please use AccountUI instead.')
+@deprecated('Please use AccountUI instead.')
 class AccountRegion(AccountUI):
     pass
 
