@@ -14,19 +14,22 @@
 #    You should have received a copy of the GNU Affero General Public License
 #    along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
+from __future__ import unicode_literals
+from __future__ import print_function
 import pkg_resources
 
-from elixir import using_options, Entity, Boolean, UnicodeText
+from elixir import using_options
 
 from nose.tools import istest
-from reahl.tofu import Fixture, test, set_up
+from reahl.tofu import Fixture
+from reahl.tofu import test
 from reahl.tofu import vassert
 from reahl.stubble import easter_egg
 
 
 from reahl.sqlalchemysupport import Session, metadata
 from reahl.web.ui import TwoColumnPage, Panel, P
-from reahl.workflowmodel import DeferredAction, Requirement, WorkflowInterface, Queue, Task, Inbox
+from reahl.workflowmodel import Task
 from reahl.domainui.workflow import InboxUI
 from reahl.web.fw import UserInterface, Url
 from reahl.domain_dev.workflowtests import TaskQueueZooMixin
@@ -41,9 +44,9 @@ class WorkflowWebFixture(Fixture, WebBasicsMixin, TaskQueueZooMixin):
     
     def new_account_bookmarks(self):
         class Bookmarks(object):
-            terms_bookmark = BookmarkStub(Url(u'/#terms'), u'Terms')
-            privacy_bookmark = BookmarkStub(Url(u'/#privacy'), u'Privacy Policy')
-            disclaimer_bookmark = BookmarkStub(Url(u'/#disclaimer'), u'Disclaimer')
+            terms_bookmark = BookmarkStub(Url('/#terms'), 'Terms')
+            privacy_bookmark = BookmarkStub(Url('/#privacy'), 'Privacy Policy')
+            disclaimer_bookmark = BookmarkStub(Url('/#disclaimer'), 'Disclaimer')
         return Bookmarks()
 
     def new_wsgi_app(self, enable_js=False):
@@ -53,11 +56,11 @@ class WorkflowWebFixture(Fixture, WebBasicsMixin, TaskQueueZooMixin):
         class MainUI(UserInterface):
             def assemble(self):
                 self.define_page(TwoColumnPage)
-                accounts = self.define_user_interface(u'/accounts', AccountUI, {u'main_slot': u'main'},
-                                              name=u'test_ui', bookmarks=fixture.account_bookmarks)
+                accounts = self.define_user_interface('/accounts', AccountUI, {'main_slot': 'main'},
+                                              name='test_ui', bookmarks=fixture.account_bookmarks)
                 login_bookmark = accounts.get_bookmark(relative_path='/login')
-                self.define_user_interface(u'/inbox',  InboxUI,  {u'main_slot': u'main'}, 
-                                   name=u'test_ui', login_bookmark=login_bookmark, get_queues=get_queues)
+                self.define_user_interface('/inbox',  InboxUI,  {'main_slot': 'main'}, 
+                                   name='test_ui', login_bookmark=login_bookmark, get_queues=get_queues)
         return super(WorkflowWebFixture, self).new_wsgi_app(enable_js=enable_js,
                                                          site_root=MainUI)
 
@@ -67,7 +70,7 @@ class WorkflowWebFixture(Fixture, WebBasicsMixin, TaskQueueZooMixin):
         return account
 
 class MyTask(Task):
-    using_options(metadata=metadata, session=Session, shortnames=True, inheritance=u'single')
+    using_options(metadata=metadata, session=Session, shortnames=True, inheritance='single')
 
 
 class MyTaskWidget(Panel):
@@ -77,7 +80,7 @@ class MyTaskWidget(Panel):
 
     def __init__(self, view, task):
         super(MyTaskWidget, self).__init__(view)
-        self.add_child(P(view, text=u'my task widget'))
+        self.add_child(P(view, text='my task widget'))
 
 
 @istest
@@ -86,11 +89,11 @@ class Tests(object):
     def detour_to_login(self, fixture):
         browser = Browser(fixture.wsgi_app)
 
-        browser.open(u'/inbox/')
+        browser.open('/inbox/')
         vassert( browser.location_path == '/accounts/login' )
-        browser.type(u'//input[@name="email"]', fixture.system_account.email)
-        browser.type(u'//input[@name="password"]', fixture.system_account.password)
-        browser.click(u'//input[@value="Log in"]')
+        browser.type('//input[@name="email"]', fixture.system_account.email)
+        browser.type('//input[@name="password"]', fixture.system_account.password)
+        browser.click('//input[@value="Log in"]')
         vassert( browser.location_path == '/inbox/' )
         
         
@@ -100,35 +103,35 @@ class Tests(object):
         browser = Browser(fixture.wsgi_app)
         task = fixture.task
 
-        take_task_button = u'//input[@value="Take"]'
-        defer_task_button = u'//input[@value="Defer"]'
-        release_task_button = u'//input[@value="Release"]'
-        go_to_task_button = u'//input[@value="Go to"]'
+        take_task_button = '//input[@value="Take"]'
+        defer_task_button = '//input[@value="Defer"]'
+        release_task_button = '//input[@value="Release"]'
+        go_to_task_button = '//input[@value="Go to"]'
 
         fixture.log_in(browser=browser)
-        browser.open(u'/inbox/')
+        browser.open('/inbox/')
     
         browser.click(take_task_button)
-        vassert( browser.location_path == u'/inbox/task/%s' % task.id )
+        vassert( browser.location_path == '/inbox/task/%s' % task.id )
 
         browser.click(defer_task_button)
-        vassert( browser.location_path == u'/inbox/' )
+        vassert( browser.location_path == '/inbox/' )
         
         browser.click(go_to_task_button)
-        vassert( browser.location_path == u'/inbox/task/%s' % task.id )
+        vassert( browser.location_path == '/inbox/task/%s' % task.id )
 
         browser.click(release_task_button)
-        vassert( browser.location_path == u'/inbox/' )
+        vassert( browser.location_path == '/inbox/' )
 
     @test(WorkflowWebFixture)
     def widgets_for_tasks(self, fixture):
         """The widget to use for displaying a particular type of task can be set via an entry point."""
         pkg_resources.working_set.add(easter_egg)
         line = 'MyTaskWidget = reahl.domainui_dev.workflowtests:MyTaskWidget' 
-        easter_egg.add_entry_point_from_line(u'reahl.workflowui.task_widgets', line)
+        easter_egg.add_entry_point_from_line('reahl.workflowui.task_widgets', line)
 
         with fixture.persistent_test_classes(MyTask):
-            task = MyTask(queue=fixture.queue, title=u'a task')
+            task = MyTask(queue=fixture.queue, title='a task')
 
             try:
                 Task.mapper.polymorphic_on = Task.table.columns['id']
@@ -139,9 +142,9 @@ class Tests(object):
 
                 browser = Browser(fixture.wsgi_app)
                 fixture.log_in(browser=browser)
-                browser.open(u'/inbox/task/%s' % task.id )
-                html = browser.get_html_for(u'//div/p')
-                vassert( html == u'<p>my task widget</p>' )
+                browser.open('/inbox/task/%s' % task.id )
+                html = browser.get_html_for('//div/p')
+                vassert( html == '<p>my task widget</p>' )
             finally:
                 Task.mapper.polymorphic_on = None
                 del MyTask.mapper.polymorphic_map[task.id] 
