@@ -20,14 +20,16 @@
 Copyright (C) 2008 Reahl Software Services (Pty) Ltd.  All rights reserved. (www.reahl.org)
 
 """
+from __future__ import unicode_literals
+from __future__ import print_function
 
 from reahl.component.config import Configuration, EntryPointClassList
 
 
 class DomainUiConfig(Configuration):
-    filename = u'domainui.config.py'
-    config_key = u'workflowui'
-    task_widgets = EntryPointClassList(u'reahl.workflowui.task_widgets', description=u'All available Widgets for displaying workflow tasks')
+    filename = 'domainui.config.py'
+    config_key = 'workflowui'
+    task_widgets = EntryPointClassList('reahl.workflowui.task_widgets', description='All available Widgets for displaying workflow tasks')
 
 
 
